@@ -1,5 +1,6 @@
 from importlib import import_module
 from pprint import pformat
+from datetime import datetime
 
 from floraconcierge import errors
 
@@ -46,3 +47,6 @@ class Object(object):
 
     def __getattr__(self, item):
         return self.__dict__.get(item)
+
+    def datetime(self, unixtime):
+        return datetime.fromtimestamp(int(unixtime))
